CDSS: CDSS: Course dependent skill structures

CDSSR Documentation

CDSS: Course dependent skill structures

Description

The CDSS package provides functions for a complete workflow from skill assignment tables to surmise mappings on the sets of skills and learning objects, respectively.

Suggested workflow for the general case

  1. Read the skill assignment using one of the read_skill_assignments_xxx() functions.

  2. Check the compliance to the definition for skill assignments using cdss_sa_compliance().

  3. Determine the attribution function on skills and on learning objects applying the cdss_skill_sa2af() and cdss_lo_sa2af() functions, respectievely.

  4. Close the attribution functions to surmise functions using kstMatrix::kmclosure().

  5. Check if the skill assignment leads to a quasi-ordinal space using cdss_sa_describes_sr().

  6. If TRUE, determine attribution relations on skills and learning objects using cdss_skill_sa2ar() and cdss_lo_sa2ar(), respectively.

  7. Close the attribution relations to surmise relations applying kstMatrix::kmclosure().

  8. Continue with functions from the kstMatrix package, e.g., to obtain a basis and further on a skill space.

Suggested workflow for the special case of one LO per skill

  1. Read the skill assignment using one of the read_skill_assignments_xxx() functions.

  2. Check whether the skill assignment allows for the derivation of a surmise relation using cdss_sa_describes_sr().

  3. If yes, derive an attribution relation from the skill assignment using cdss_skill_sa2ar().

  4. Close the attribution relation to a surmise relation using kstMatrix::kmclosure().

  5. Continue with functions from the kstMatrix package, e.g., to obtain a basis and further on a skill space.

Data files

The installation of this package includes several data files as examples in the extdata sub directory (see the Examples below for how to access the files there). There are four data sets, KST, KST-Intro, SkillAssignment, and ErroneousSkillAssignment. The SkillAssignment data set is available in three formats, ODS, XLSX, and CSV (in CSV format, there are two files each, SkillAssignment-R.csv and SkillAssignment-T.csv, for required and taught skills, respectively). The other three data sets are available in ODS format only.

SkillAssignment and ErroneousSkillAssignment are small example data sets where the latter fails for cdss_sa_compliance(). KST contains a skill assignment for the course on knowledge space theory under https://moodle.qhelp.eu/. KST-Intro contains the reduction of KST to the first chapter of that course.

References

Hockemeyer, C. (2022). Building Course-Dependent Skill Structures - Applying Competence based Knowledge Space Theory to Itself. Manuscript in preparation.

Acknowledgements

The creation of this R package was financially supported by the Erasmus+ Programme of the European Commission through the QHELP project (https://qhelp.eu/).

Examples

library(readODS)
fpath <- system.file("extdata", "SkillAssignment.ods", package="CDSS")
sa <- cdss_read_skill_assignment_ods(fpath)
sa
ssf <- kstMatrix::kmclosure(cdss_skill_sa2af(sa))
ssf
lsf <- kstMatrix::kmclosure(cdss_lo_sa2af(sa))
lsf


CDSS documentation built on Sept. 7, 2026, 9:08 a.m.

Related to CDSS in CDSS...