Learn R Programming

CDSS (version 0.3-0)

cdss_lo_csma2sf: Derive a surmise function between learning objects from a complete skill multi-assignment

Description

cdss_lo_csma2sf expects a complete skill multi-assignment and derives a surmise function on the set of learning objects.

Usage

cdss_lo_csma2sf(csma)

Value

Object of class cdss_sf (attribution function).

Arguments

csma

Complete skill multi-assignment object

See Also

Other functions building skill (multi) assignment matrices: cdss_lo_sa2af(), cdss_sa2sma(), cdss_tables2sa()