cdss_lo_sa2ar: Create an attribution relation on learning objects from a...

View source: R/cdss_lo_sa2ar.R

cdss_lo_sa2arR Documentation

Create an attribution relation on learning objects from a skill assignment.

Description

cdss_lo_sa2ar expects a skill assignment and derives an attribution relation on learning objects if the skill assignment fulfills the necessary conditions, i.e. if there is only one teaching LO per skill.

Usage

cdss_lo_sa2ar(sa)

Arguments

sa

Skill assignment object

Value

attribution relation or NULL

See Also

Other functions deriving skill structures from skill assignments: cdss_sa2ar_skill(), cdss_sa_describes_sr()


CDSS documentation built on April 27, 2026, 9:07 a.m.