Learn R Programming

CDSS (version 0.3-0)

cdss_sa2ar_skill: Create an attribution relation on skills from a skill assignment.

Description

cdss_sa2ar_skill expects a skill assignment and derives an attribution relation on skills if the skill assignment fulfills the necessary conditions, i.e. if there is only one teaching LO per skill.

Usage

cdss_sa2ar_skill(sa)

Value

attribution relation or NULL

Arguments

sa

Skill assignment object

See Also

Other functions deriving skill structures from skill assignments: cdss_lo_sa2ar(), cdss_sa_describes_sr()