cdss_sa_compliance: Check whether a skill assignment is compliant to the CDCS...

View source: R/cdss_sa_compliance.R

cdss_sa_complianceR Documentation

Check whether a skill assignment is compliant to the CDCS conditions.

Description

cdss_sa_compliance expects a skill assignment and checks whether it is compliant to the conditions for CDCS.

Usage

cdss_sa_compliance(sa, verbose = FALSE)

Arguments

sa

Skill assignment

verbose

Verbosity (default = FALSE)

Value

Boolean

See Also

Other Functions testing validity of skill assignments: cdss_circular_requirements(), cdss_missing_los(), cdss_nonteaching_los()


CDSS documentation built on Sept. 7, 2026, 9:08 a.m.