cdss_skill_sa2af: Determine Attribution function for skills from a skill...

View source: R/cdss_skill_sa2af.R

cdss_skill_sa2afR Documentation

Determine Attribution function for skills from a skill assignment

Description

cdss_skill_sa2af expects a skill assignment and derives an attribution function on the set of learning objects.

Usage

cdss_skill_sa2af(sa)

Arguments

sa

Skill assignment object

Value

Object of class kmattributionfunction

See Also

Other functions building skill (multi) assignment matrices: cdss_lo_sa2af(), cdss_tables2sa()


CDSS documentation built on Sept. 7, 2026, 9:08 a.m.