cdss_skill_sa2ar: Create an attribution relation on skills from a skill...

View source: R/cdss_skill_sa2ar.R

cdss_skill_sa2arR Documentation

Create an attribution relation on skills from a skill assignment.

Description

cdss_skill_sa2ar expects a skill assignment and derives an attribution relation on skills if the skill assignment fulfills the necessary conditions, i.e. if there is only one teaching LO per skill.

Usage

cdss_skill_sa2ar(sa)

Arguments

sa

Skill assignment object

Value

attribution relation or NULL

See Also

Other functions deriving skill structures from skill assignments: cdss_lo_sa2ar(), cdss_sa_describes_sr()


CDSS documentation built on Sept. 7, 2026, 9:08 a.m.