cdss_sma2csma: Complete a skill multi-assignment

View source: R/cdss_sma2csma.R

cdss_sma2csmaR Documentation

Complete a skill multi-assignment

Description

cdss_sma2csma expects a skill multi-assignment object and returns the corresponding complete skill multi-assignment. If this would involve cycles, the function stops by default - except if allowcycles is set to TRUE. In that case, the result may be ill-defined!

Usage

cdss_sma2csma(sma, allowcycles = FALSE)

Arguments

sma

Skill multi-assignment to be completed

allowcycles

Whether prerequisite cycles should be allowed (default = FALSE)

Value

Object of class cdss_csma.


CDSS documentation built on April 27, 2026, 9:07 a.m.