cdss_tables2sa expects two data frames with two columns each. The first
column contains the IDs of learning objects and the second row the IDs of single skills
required or taught, respectively, by this learning object.
It returns a list of two binary matrices, "taught" and "required". Each matrix has one
row per learning object and one column per skill. The cells contain a "1" if the skill
is taught or required, respectively, by the learning object and a "0" otherwise.
cdss_tables2sa(taught, required)List of two binary matrices, "taught" and "required".
Data table containing the assignment of taught skills to learning objects
Data table containing the assignment of required skills to learning objects
Other functions building skill (multi) assignment matrices:
cdss_lo_csma2sf(),
cdss_lo_sa2af(),
cdss_sa2sma()