Learn R Programming

CDSS (version 0.3-0)

cdss_lo_sa2ar: Create an attribution relation on learning objects from a skill assignment.

Description

cdss_lo_sa2ar expects a skill assignment and derives an attribution relation on learning objects if the skill assignment fulfills the necessary conditions, i.e. if there is only one teaching LO per skill.

Usage

cdss_lo_sa2ar(sa)

Value

attribution relation or NULL

Arguments

sa

Skill assignment object

See Also

Other functions deriving skill structures from skill assignments: cdss_sa2ar_skill(), cdss_sa_describes_sr()