cdss_lo_sa2ar expects a skill assignment and derives an attribution relation
on learning objects if the skill assignment fulfills the necessary conditions, i.e. if
there is only one teaching LO per skill.
cdss_lo_sa2ar(sa)attribution relation or NULL
Skill assignment object
Other functions deriving skill structures from skill assignments:
cdss_sa2ar_skill(),
cdss_sa_describes_sr()