View source: R/cdss_read_skill_assignment.R
| cdss_read_skill_assignment | R Documentation |
Read a skill assignment from file
cdss_read_skill_assignment(
filename = NULL,
taught = "Taught",
required = "Required",
sep = ",",
warnonly = FALSE,
verbose = FALSE
)
filename |
Name of the file for ODS or XLSX files |
taught |
Name of the sheet/file for taught skill assignments |
required |
Name of the sheet/file for required skil assignments |
sep |
Cell-separating character for CSV files |
warnonly |
Are non-compliant SAs allowed? (default FALSE) |
verbose |
Verbosity (default TRUE) |
Skill assignment ('cdss_sa' object)
Skill assignments are stored in a pair of tables, 'taught' and 'required'. For ODS and XLSX files, these must be sheets of **one** file; CSV does not support multi-sheet file and, therefore, two files must be specified there.
For CSV files, the 'filename' parameter must be 'NULL', and the two filenames are specified in the 'taught' and 'required' parameters. For ODS and XLSX, the 'filename' must be specified, and teh 'taught' and 'required' parameters specify the names of the respective sheets within that file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.