cdss_sa2ar_skill expects a skill assignment and derives an attribution relation
on skills if the skill assignment fulfills the necessary conditions, i.e. if there
is only one teaching LO per skill.
cdss_sa2ar_skill(sa)attribution relation or NULL
Skill assignment object
Other functions deriving skill structures from skill assignments:
cdss_lo_sa2ar(),
cdss_sa_describes_sr()