Learn R Programming

CDSS (version 0.3-0)

cdss_sa_compliance: Check whether a skill assignment is compliant to the CDCS conditions.

Description

cdss_sa_compliance expects a skill assignment and checks whether it is compliant to the conditions for CDCS.

Usage

cdss_sa_compliance(sa, warnings = FALSE)

Value

Boolean

Arguments

sa

Skill assignment

warnings

Toggles whether warnings should be printed

See Also

Other Functions testing validity of skill assignments: cdss_circular_requirements(), cdss_missing_los(), cdss_nonteaching_los()