View source: R/cdss_skill_sa2ar.R
| cdss_skill_sa2ar | R Documentation |
cdss_skill_sa2ar expects a skill assignment and derives an attribution relation
on skills if the skill assignment fulfills the necessary conditions, i.e. if there
is only one teaching LO per skill.
cdss_skill_sa2ar(sa)
sa |
Skill assignment object |
attribution relation or NULL
Other functions deriving skill structures from skill assignments:
cdss_lo_sa2ar(),
cdss_sa_describes_sr()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.